==> openGion6.6.0.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2016/10/27 10:56:51                                            */
/****************************************************************************/

CREATE TABLE GE34 (
   YKNO     INTEGER             DEFAULT 0   NOT NULL                                                /*  10 要求NO   */
 , GROUP_ID VARCHAR (  20 )                                                                         /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   VARCHAR (  10 )                 NOT NULL                                                /*  30 社員番号 */
 , DST_NAME VARCHAR ( 100 )                                                                         /*  40 名前     */
 , DST_ADDR VARCHAR ( 100 )                                                                         /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  VARCHAR (   1 )                 NOT NULL                                                /*  60 送信区分 */
 , UNIQ     BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR (  14 )                                                                         /* 820 登録日時 */
 , PGSET    VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET   VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET   VARCHAR (  10 )                                                                         /* 850 作成社員 */
 , DYUPD    VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD    VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD   VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD   VARCHAR (  10 )                                                                         /* 890 更新者   */
);

==> openGion7.2.4.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE34S.sql <==
/****************************************************************************/
/* GE34 ( 宛先ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE34 (
   YKNO     INTEGER             DEFAULT 0   NOT NULL                                                /*  10 要求NO   */
 , GROUP_ID VARCHAR (  20 )                                                                         /*  20 ｸﾞﾙｰﾌﾟID */
 , DST_ID   VARCHAR (  10 )                 NOT NULL                                                /*  30 社員番号 */
 , DST_NAME VARCHAR ( 100 )                                                                         /*  40 名前     */
 , DST_ADDR VARCHAR ( 100 )                                                                         /*  50 ﾒｰﾙｱﾄﾞﾚｽ */
 , DST_KBN  VARCHAR (   1 )                 NOT NULL                                                /*  60 送信区分 */
 , UNIQ     BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ      VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET    VARCHAR (  14 )                                                                         /* 820 登録日時 */
 , PGSET    VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET   VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET   VARCHAR (  10 )                                                                         /* 850 作成者   */
 , DYUPD    VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD    VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD   VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD   VARCHAR (  10 )                                                                         /* 890 更新者   */
);
